% Report template 
% Author
% {today}

### Cover_type

{Cover_type}

### shape

{shape}

### dtypes

{dtypes}

### skew

{skew}

### description

{description}

### Corr

![]({Corr})

### select_method{{.fragile}}

```{{.python}}
{select_method}
```

### features_remain_with_thres_as_70

{features_remain_with_thres_as_70}

